<?php
// prevent direct calls to this file from doing anything.
if(!defined('ABSPATH') || !defined('WPINC'))
{
	die();
}

class PNDL_FeaturedProductWidget extends WP_Widget
{
	const productQuery = 'SELECT products.id,products.name,products.description,product_category.category_id FROM %1$swpsc_product_list AS products LEFT JOIN %1$swpsc_item_category_assoc AS product_category ON products.id=product_category.product_id WHERE products.id=%2$d AND products.publish=1 AND products.active=1';
	const randomQuery  = 'SELECT products.id,products.name,products.description,product_category.category_id FROM %1$swpsc_product_list AS products LEFT JOIN %1$swpsc_item_category_assoc AS product_category ON products.id=product_category.product_id WHERE products.publish=1 AND products.active=1 ORDER BY rand() LIMIT 1';

	function __construct()
	{
		// construct the widget with "Base ID" set to false - if set, the base ID appears in the html 'id' attribute. 
		parent::__construct(false, "Featured Product");
	}

	function widget($args, $instance)
	{
		// extract general widget arguments ($before_title etc)
		extract($args);
		// extract instance fields $productid and $title
		extract($instance);

		// do not display the widget if we can't detect the e-Commerce plugin
		if (!function_exists('wpsc_product_url'))
		{
			return;
		}

		$results = array();
		// perform product-specific query if we have a valid product ID
		global $wpdb;
		if ($productid > 0)
		{
			$results = $wpdb->get_results(sprintf(PNDL_FeaturedProductWidget::productQuery, $wpdb->prefix, $productid), ARRAY_A);
		}
		// if either our product-specific results are empty, or we didn't have a valid product ID, perform a random query.
		if (count($results) == 0)
		{
			$results = $wpdb->get_results(sprintf(PNDL_FeaturedProductWidget::randomQuery, $wpdb->prefix), ARRAY_A);
		}

		// if we still do not have any results, then do not display the widget.
		if (count($results) < 1)
		{
			return;
		}

		$title = $title ? $title : "Featured Product";
		// allow registered widget_title filters to filter the title
		$title = apply_filters('widget_title', $instance['title']);

		$productName = $results[0]['name'];
		$productDetail = $results[0]['description'];
		$productHREF = wpsc_product_url($results[0]['id'], $results[0]['category_id']);
		echo $before_widget;

		if ($title)
			echo $before_title . $title . $after_title;

		echo "<p><a href=\"$productHREF\"><strong>$productName</strong></a></p>";
		echo "<p>$productDetail</p>";
		echo $after_widget;
	}

	function update($new_instance, $old_instance)
	{
		return array("productid"=>(int)$new_instance["productid"], "title"=>strip_tags($new_instance["title"]));
	}

	function form($instance)
	{
		// widget title
		echo "<p>";
		echo "<label for=" . $this->get_field_id('title') . ">Title:</label>";
		echo "<input id=" . $this->get_field_id('title') . " name=" . $this->get_field_name('title') . " value=\"" .
			$instance['title'] . "\" class=\"widefat\" type=\"text\" />";
		echo "</p>";

		// return early if e-Commerce plugin is not available
		if (!function_exists('wpsc_product_url'))
		{
			echo "<p><strong>Warning:</strong> This widget works with the \"WP e-Commerce\" plugin, which has not been detected on your installation. It is therefore currently not possible to select a featured product.</p>";
			return;
		}

		// product selection
		// get available products
		global $wpdb;
		$results = $wpdb->get_results("SELECT products.id,products.name,products.description,product_category.category_id FROM wp_wpsc_product_list AS products LEFT JOIN wp_wpsc_item_category_assoc AS product_category ON products.id=product_category.product_id WHERE products.publish=1 AND products.active=1 ORDER BY products.name", ARRAY_A);
		echo "<p>";
		if (!$results || count($results) == 0)
		{
			echo "There are currently no products publicly available on your website. Check that you have at least one product in your store, and that it has been \"published\".";
		}
		else
		{
			echo "<label for=" . $this->get_field_id('productid') . ">Product:</label>\n";
			echo "<select id=" . $this->get_field_id('productid') . " name=" . $this->get_field_name('productid') . " value=\"" .
				$instance['productid'] . "\" class=\"widefat\">\n";
			echo "<option value=\"-1\">Random Product</option>\n";
			foreach ($results as $result)
			{
				$selected = ($result['id'] == $instance['productid']) ? " selected" : "";
				echo "<option value=\"". $result['id'] ."\"$selected>".$result['name']."</option>\n";
			}
			echo "</select>\n";
		}
		echo "</p>\n";
	}
}
?>